@@ -52,8 +52,24 @@ class RNAdvisorCLI:
             self.native_path, self.pred_dir
         )
         self.scores = check_scores(self.scores)
-        # build_docker(self.scores)
         self.volumes = self.add_volumes()
+        self.init_params()
+
+    def init_params(self):
+        """
+        Initialize the parameters for the different scoring functions.
+        """
+        if self.params is None:
+            self.params = {}
+        if isinstance(self.params, str):
+            try:
+                self.params = json.loads(self.params)
+            except json.JSONDecodeError:
+                logger.warning("Invalid JSON string for params. Using empty dict.")
+                self.params = {}
+        if not isinstance(self.params, dict):
+            logger.warning("Invalid type for params. Using empty dict.")
+            self.params = {}
 
     def convert_cif_files_to_pdb(
         self, native_path: Optional[str], pred_dir: Optional[str]
@@ -224,11 +240,12 @@ class RNAdvisorCLI:
         services = {}
         for key in self.scores:
             service = SERVICES_DICT[key]
-            # No out_path here because it is set in tmp dir
             params = (
                 json.dumps(self.params)
-                if isinstance(self.params, dict) and self.params
+                if isinstance(self.params, dict)
                 else self.params
+                if isinstance(self.params, str) and self.params.strip()
+                else None
             )
             service["args"].update(
                 {
